@@ -2,8 +2,9 @@ package Perl::Critic::Policy::Moose::ProhibitNewMethod;
 
 use strict;
 use warnings;
+use namespace::autoclean;
 
-our $VERSION = '1.04';
+our $VERSION = '1.05';
 
 use Readonly ();
 
@@ -93,13 +94,15 @@ __END__
 
 =pod
 
+=encoding UTF-8
+
 =head1 NAME
 
 Perl::Critic::Policy::Moose::ProhibitNewMethod - Don't override Moose's standard constructors.
 
 =head1 VERSION
 
-version 1.04
+version 1.05
 
 =head1 DESCRIPTION
 
@@ -141,6 +144,13 @@ then the following code would result in a violation:
 
 =back
 
+=head1 SUPPORT
+
+Bugs may be submitted through L<the RT bug tracker|http://rt.cpan.org/Public/Dist/Display.html?Name=Perl-Critic-Moose>
+(or L<bug-perl-critic-moose@rt.cpan.org|mailto:bug-perl-critic-moose@rt.cpan.org>).
+
+I am also usually active on IRC as 'drolsky' on C<irc://irc.perl.org>.
+
 =head1 AUTHORS
 
 =over 4
@@ -157,7 +167,7 @@ Dave Rolsky <autarch@urth.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2008 - 2015 by Elliot Shank.
+This software is copyright (c) 2008 - 2016 by Elliot Shank.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
